==> driza-0.5.tar.gz: driza-0.5.0/Driza/operaciones/jicuadrado.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#jicuadrado.py Operación jicuadrado

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from rpy import *
from Driza.widgets import wopciones

def funcion(dato,variable,cosa,opciones):
	lista=[int(x) for x in dato[variable]]
	num=len(lista)
	if opciones[u"Distribución"]=="Uniforme":
		distribucion=r.runif(num,1./num,1./num)
	resultado=r.chisq_test(lista,p=distribucion)
	#resultado=r.chisq_test(lista,r.rep(1./num,num))
	resultado["Percentil"]=opciones["Percentil"] # Pasa al resultado sin procesar
	return resultado

def initresultado(resultado,opciones):
	resultado.addTabla("resultado")
	resultado["resultado"].titulo="Ji Cuadrado"
	lista=["Percentil limite","percentil obtenido","Conclusión"]
	resultado["resultado"].settitulo(lista)

def interfazresultado(resultado,variable,caso,diccionario):
	lista=[]
	lista.append(diccionario["Percentil"])
	lista.append(diccionario["p.value"])
	if diccionario["p.value"]*100>diccionario["Percentil"]:
		lista.append("Se ajusta a la distribucion")
	else:
		lista.append("No se ajusta a la distribucion")
	resultado["resultado"].set(variable,caso,lista)

widget={"tipo":"BondadDeAjuste"}


#blblbl

==> driza-0.5.2.tar.gz: driza-0.5.2/Driza/operaciones/jicuadrado.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#jicuadrado.py Operación jicuadrado

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from rpy import *
from Driza.widgets import wopciones

def funcion(dato,variable,cosa,opciones):
	lista=[float(x) for x in dato[variable]]
	num=len(lista)
	if opciones[u"Distribución"]=="Uniforme":
		distribucion=r.runif(num,1./num,1./num)
	resultado=r.chisq_test(lista,p=distribucion)
	#resultado=r.chisq_test(lista,r.rep(1./num,num))
	resultado["Percentil"]=opciones["Percentil"] # Pasa al resultado sin procesar
	return resultado

def initresultado(resultado,opciones):
	resultado.addTablaSimple("resultado")
	resultado["resultado"].titulo="Ji Cuadrado"
	lista=["Percentil limite","percentil obtenido","Conclusión"]
	resultado["resultado"].settitulo(lista)

def interfazresultado(resultado,listaopciones):
	variable=listaopciones[0]
	caso=listaopciones[1]
	diccionario=listaopciones[2]
	lista=[]
	lista.append(diccionario["Percentil"])
	lista.append(diccionario["p.value"])
	if diccionario["p.value"]*100>diccionario["Percentil"]:
		lista.append("Se ajusta a la distribucion")
	else:
		lista.append("No se ajusta a la distribucion")
	resultado["resultado"].set(variable,caso,lista)

widget={"tipo":"BondadDeAjuste"}
